@@ -62,7 +62,8 @@ class SecretManagerServiceClientMeta(type):
     _transport_registry["grpc_asyncio"] = SecretManagerServiceGrpcAsyncIOTransport
 
     def get_transport_class(
-        cls, label: str = None,
+        cls,
+        label: str = None,
     ) -> Type[SecretManagerServiceTransport]:
         """Returns an appropriate transport class.
 
@@ -175,10 +176,14 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         return self._transport
 
     @staticmethod
-    def secret_path(project: str, secret: str,) -> str:
+    def secret_path(
+        project: str,
+        secret: str,
+    ) -> str:
         """Returns a fully-qualified secret string."""
         return "projects/{project}/secrets/{secret}".format(
-            project=project, secret=secret,
+            project=project,
+            secret=secret,
         )
 
     @staticmethod
@@ -188,10 +193,16 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def secret_version_path(project: str, secret: str, secret_version: str,) -> str:
+    def secret_version_path(
+        project: str,
+        secret: str,
+        secret_version: str,
+    ) -> str:
         """Returns a fully-qualified secret_version string."""
         return "projects/{project}/secrets/{secret}/versions/{secret_version}".format(
-            project=project, secret=secret, secret_version=secret_version,
+            project=project,
+            secret=secret,
+            secret_version=secret_version,
         )
 
     @staticmethod
@@ -204,9 +215,15 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def topic_path(project: str, topic: str,) -> str:
+    def topic_path(
+        project: str,
+        topic: str,
+    ) -> str:
         """Returns a fully-qualified topic string."""
-        return "projects/{project}/topics/{topic}".format(project=project, topic=topic,)
+        return "projects/{project}/topics/{topic}".format(
+            project=project,
+            topic=topic,
+        )
 
     @staticmethod
     def parse_topic_path(path: str) -> Dict[str, str]:
@@ -215,7 +232,9 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_billing_account_path(billing_account: str,) -> str:
+    def common_billing_account_path(
+        billing_account: str,
+    ) -> str:
         """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
@@ -228,9 +247,13 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_folder_path(folder: str,) -> str:
+    def common_folder_path(
+        folder: str,
+    ) -> str:
         """Returns a fully-qualified folder string."""
-        return "folders/{folder}".format(folder=folder,)
+        return "folders/{folder}".format(
+            folder=folder,
+        )
 
     @staticmethod
     def parse_common_folder_path(path: str) -> Dict[str, str]:
@@ -239,9 +262,13 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_organization_path(organization: str,) -> str:
+    def common_organization_path(
+        organization: str,
+    ) -> str:
         """Returns a fully-qualified organization string."""
-        return "organizations/{organization}".format(organization=organization,)
+        return "organizations/{organization}".format(
+            organization=organization,
+        )
 
     @staticmethod
     def parse_common_organization_path(path: str) -> Dict[str, str]:
@@ -250,9 +277,13 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_project_path(project: str,) -> str:
+    def common_project_path(
+        project: str,
+    ) -> str:
         """Returns a fully-qualified project string."""
-        return "projects/{project}".format(project=project,)
+        return "projects/{project}".format(
+            project=project,
+        )
 
     @staticmethod
     def parse_common_project_path(path: str) -> Dict[str, str]:
@@ -261,10 +292,14 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_location_path(project: str, location: str,) -> str:
+    def common_location_path(
+        project: str,
+        location: str,
+    ) -> str:
         """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
-            project=project, location=location,
+            project=project,
+            location=location,
         )
 
     @staticmethod
@@ -529,12 +564,20 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListSecretsPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -660,7 +703,12 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -767,7 +815,12 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -865,7 +918,12 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -973,7 +1031,12 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1056,7 +1119,10 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
 
         # Send the request.
         rpc(
-            request, retry=retry, timeout=timeout, metadata=metadata,
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
         )
 
     def list_secret_versions(
@@ -1154,12 +1220,20 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListSecretVersionsPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -1261,7 +1335,12 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1363,7 +1442,12 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1463,7 +1547,12 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1563,7 +1652,12 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1664,7 +1758,12 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1794,7 +1893,12 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1920,7 +2024,12 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1997,7 +2106,12 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
