@@ -60,7 +60,8 @@ class SecretManagerServiceClientMeta(type):
     _transport_registry["grpc_asyncio"] = SecretManagerServiceGrpcAsyncIOTransport
 
     def get_transport_class(
-        cls, label: str = None,
+        cls,
+        label: str = None,
     ) -> Type[SecretManagerServiceTransport]:
         """Return an appropriate transport class.
 
@@ -170,10 +171,14 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         return self._transport
 
     @staticmethod
-    def secret_path(project: str, secret: str,) -> str:
+    def secret_path(
+        project: str,
+        secret: str,
+    ) -> str:
         """Return a fully-qualified secret string."""
         return "projects/{project}/secrets/{secret}".format(
-            project=project, secret=secret,
+            project=project,
+            secret=secret,
         )
 
     @staticmethod
@@ -183,10 +188,16 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def secret_version_path(project: str, secret: str, secret_version: str,) -> str:
+    def secret_version_path(
+        project: str,
+        secret: str,
+        secret_version: str,
+    ) -> str:
         """Return a fully-qualified secret_version string."""
         return "projects/{project}/secrets/{secret}/versions/{secret_version}".format(
-            project=project, secret=secret, secret_version=secret_version,
+            project=project,
+            secret=secret,
+            secret_version=secret_version,
         )
 
     @staticmethod
@@ -199,7 +210,9 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_billing_account_path(billing_account: str,) -> str:
+    def common_billing_account_path(
+        billing_account: str,
+    ) -> str:
         """Return a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
@@ -212,9 +225,13 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_folder_path(folder: str,) -> str:
+    def common_folder_path(
+        folder: str,
+    ) -> str:
         """Return a fully-qualified folder string."""
-        return "folders/{folder}".format(folder=folder,)
+        return "folders/{folder}".format(
+            folder=folder,
+        )
 
     @staticmethod
     def parse_common_folder_path(path: str) -> Dict[str, str]:
@@ -223,9 +240,13 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_organization_path(organization: str,) -> str:
+    def common_organization_path(
+        organization: str,
+    ) -> str:
         """Return a fully-qualified organization string."""
-        return "organizations/{organization}".format(organization=organization,)
+        return "organizations/{organization}".format(
+            organization=organization,
+        )
 
     @staticmethod
     def parse_common_organization_path(path: str) -> Dict[str, str]:
@@ -234,9 +255,13 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_project_path(project: str,) -> str:
+    def common_project_path(
+        project: str,
+    ) -> str:
         """Return a fully-qualified project string."""
-        return "projects/{project}".format(project=project,)
+        return "projects/{project}".format(
+            project=project,
+        )
 
     @staticmethod
     def parse_common_project_path(path: str) -> Dict[str, str]:
@@ -245,10 +270,14 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_location_path(project: str, location: str,) -> str:
+    def common_location_path(
+        project: str,
+        location: str,
+    ) -> str:
         """Return a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
-            project=project, location=location,
+            project=project,
+            location=location,
         )
 
     @staticmethod
@@ -443,12 +472,20 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListSecretsPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -556,7 +593,12 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -646,7 +688,12 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -727,7 +774,12 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -819,7 +871,12 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -889,7 +946,10 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
 
         # Send the request.
         rpc(
-            request, retry=retry, timeout=timeout, metadata=metadata,
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
         )
 
     def list_secret_versions(
@@ -969,12 +1029,20 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListSecretVersionsPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -1058,7 +1126,12 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1139,7 +1212,12 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1221,7 +1299,12 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1303,7 +1386,12 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1386,7 +1474,12 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1498,7 +1591,12 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1606,7 +1704,12 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1664,7 +1767,12 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
