@@ -227,8 +227,7 @@ class SecretManagerServiceGrpcTransport(SecretManagerServiceTransport):
 
     @property
     def grpc_channel(self) -> grpc.Channel:
-        """Return the channel designed to connect to this service.
-        """
+        """Return the channel designed to connect to this service."""
         return self._grpc_channel
 
     @property
